==> ogre-next-2.3.3-1-x86_64.pkg.tar.zst: usr/share/OGRE-Next/docs/api/html/search/variables_c.js <==
var searchData=
[
  ['l_0',['l',['../struct_x_client_message_event_data.html#af9ab2e94eb01f68d26563596eb428490',1,'XClientMessageEventData']]],
  ['language_1',['language',['../struct_ogre_1_1_material_script_program_definition.html#a634973d853b04b2cf2af2133d504b257',1,'Ogre::MaterialScriptProgramDefinition']]],
  ['lastcameraposition_2',['lastCameraPosition',['../struct_ogre_1_1_vct_cascade_setting.html#a33b22a34969b7c53ec4003a77b54198e',1,'Ogre::VctCascadeSetting']]],
  ['lastcfactor_3',['lastCFactor',['../struct_ogre_1_1_terrain_quad_tree_node_1_1_lod_level.html#afd5d89ee1eaff154e44347c15af2fba3',1,'Ogre::TerrainQuadTreeNode::LodLevel']]],
  ['lastframeused_4',['lastframeused',['../struct_ogre_1_1_metal_discard_buffer_manager_1_1_unsafe_block.html#a88709353f3c121f08e43392024c70aaa',1,'Ogre::MetalDiscardBufferManager::UnsafeBlock::lastFrameUsed'],['../struct_ogre_1_1_vulkan_discard_buffer_manager_1_1_unsafe_block.html#aa674970178b2b2dc1a34736c98edd4bf',1,'Ogre::VulkanDiscardBufferManager::UnsafeBlock::lastFrameUsed']]],
  ['lastrq_5',['lastRq',['../struct_ogre_1_1_cull_frustum_request.html#ad755d947a31cb517bf34b254577a5257',1,'Ogre::CullFrustumRequest']]],
  ['lasttransitiondist_6',['lastTransitionDist',['../struct_ogre_1_1_terrain_quad_tree_node_1_1_lod_level.html#ac82a3ddf378272493d9d82100c17597a',1,'Ogre::TerrainQuadTreeNode::LodLevel']]],
  ['layer_5fshadow_5fcaster_7',['LAYER_SHADOW_CASTER',['../namespace_ogre_1_1_visibility_flags.html#ab83dacba6153c77d0ea4af5b5f66b07a',1,'Ogre::VisibilityFlags']]],
  ['layer_5fvisibility_8',['LAYER_VISIBILITY',['../namespace_ogre_1_1_visibility_flags.html#a6ef94007305f4ec3dea21e757e3e7fdf',1,'Ogre::VisibilityFlags']]],
  ['layerdeclaration_9',['layerDeclaration',['../struct_ogre_1_1_terrain_1_1_import_data.html#ae3203cf7a78bd3ed0cd75ffe3c107a2e',1,'Ogre::Terrain::ImportData']]],
  ['layerlist_10',['layerList',['../struct_ogre_1_1_terrain_1_1_import_data.html#a3d892ce610f8e6aec873528d042fe72b',1,'Ogre::Terrain::ImportData']]],
  ['layout_11',['layout',['../struct_ogre_1_1_resource_status.html#a2c7d5e06a053baa33611c5a30587ab45',1,'Ogre::ResourceStatus']]],
  ['left_12',['left',['../struct_ogre_1_1_t_rect.html#a7f8310e37638f8790a89f2dd64ff3fe1',1,'Ogre::TRect::left'],['../struct_ogre_1_1_box.html#a88fa61f841bc444d92075d8b6cb2b43b',1,'Ogre::Box::left']]],
  ['lefteyecenter_13',['leftEyeCenter',['../struct_ogre_1_1_hidden_area_vr_settings.html#a61eb37968fd8752cef5be018173a7ab6',1,'Ogre::HiddenAreaVrSettings']]],
  ['lefteyeradius_14',['leftEyeRadius',['../struct_ogre_1_1_hidden_area_vr_settings.html#afbda8be8da981a34199b3786bf1660a3',1,'Ogre::HiddenAreaVrSettings']]],
  ['leftnosecenter_15',['leftNoseCenter',['../struct_ogre_1_1_hidden_area_vr_settings.html#af6f880a9fb10883cfdcd0977de3345de',1,'Ogre::HiddenAreaVrSettings']]],
  ['leftnoseradius_16',['leftNoseRadius',['../struct_ogre_1_1_hidden_area_vr_settings.html#a80aa7c9981f0fb82d2516ed2a1e1ef24',1,'Ogre::HiddenAreaVrSettings']]],
  ['legacymathbrdf_17',['LegacyMathBrdf',['../struct_ogre_1_1_pbs_property.html#aa400163e80e15674460f24e2f0073d89',1,'Ogre::PbsProperty']]],
  ['length_18',['length',['../struct_ogre_1_1_staging_buffer_1_1_destination.html#a94ed749fd12ea165bca3aa12f746eb44',1,'Ogre::StagingBuffer::Destination::length'],['../struct_ogre_1_1_stream_serialiser_1_1_chunk.html#aee59026e7658bc15408b2f92ee1140cb',1,'Ogre::StreamSerialiser::Chunk::length']]],
  ['level_19',['level',['../struct_ogre_1_1_volume_1_1_chunk_request.html#ae5e6c6ee00b6c824bcc782266a440c42',1,'Ogre::Volume::ChunkRequest']]],
  ['levels_20',['levels',['../struct_ogre_1_1_lod_config.html#a7eecc87589b5a3eacfa363850c2fe4c0',1,'Ogre::LodConfig']]],
  ['lexemelen_21',['lexemeLen',['../struct_ogre_1_1_script_token.html#ad065a5c8a457b5e951e2e8f7a79d29f4',1,'Ogre::ScriptToken']]],
  ['lexemeptr_22',['lexemePtr',['../struct_ogre_1_1_script_token.html#a3ff89cd1a7a0a9aa09aee101b354d2e3',1,'Ogre::ScriptToken']]],
  ['light_23',['light',['../struct_ogre_1_1_light_closest.html#aa41b81d253b1af2e9951905238e0a7dc',1,'Ogre::LightClosest::light'],['../class_ogre_1_1_shadow_texture_definition.html#ac5fa1aa9cea5f1ef578cbd4b16196e42',1,'Ogre::ShadowTextureDefinition::light']]],
  ['lightmask_24',['lightMask',['../struct_ogre_1_1_vct_cascade_setting.html#a662957795b2fc34af807f72fb87c0ad1',1,'Ogre::VctCascadeSetting']]],
  ['lightprofilestexture_25',['LightProfilesTexture',['../struct_ogre_1_1_pbs_property.html#acbf91dda99dc9f01792ced8ca41e795d',1,'Ogre::PbsProperty']]],
  ['lights_26',['lights',['../struct_ogre_1_1_light_list_info.html#a29f8b2d7075f792fe24454a5a37b09d0',1,'Ogre::LightListInfo']]],
  ['lightsareaapprox_27',['LightsAreaApprox',['../struct_ogre_1_1_hlms_base_prop.html#aadab57242035ec68cef4db1aa1db601f',1,'Ogre::HlmsBaseProp']]],
  ['lightsarealtc_28',['LightsAreaLtc',['../struct_ogre_1_1_hlms_base_prop.html#afc34b6b99ecc65879f88059d2aa1c4e0',1,'Ogre::HlmsBaseProp']]],
  ['lightsareatexcolour_29',['LightsAreaTexColour',['../struct_ogre_1_1_hlms_base_prop.html#a331c39fb20c11a18fe8677aad9abca78',1,'Ogre::HlmsBaseProp']]],
  ['lightsareatexmask_30',['LightsAreaTexMask',['../struct_ogre_1_1_hlms_base_prop.html#a91ce66216630c5c9c4ec80a169b0abcf',1,'Ogre::HlmsBaseProp']]],
  ['lightsattenuation_31',['LightsAttenuation',['../struct_ogre_1_1_hlms_base_prop.html#a30a8aaf4edf7c988a87ebc7d620f1288',1,'Ogre::HlmsBaseProp']]],
  ['lightsdirectional_32',['LightsDirectional',['../struct_ogre_1_1_hlms_base_prop.html#ad7fc41fdaebead65e4dd966e5b0a0f6e',1,'Ogre::HlmsBaseProp']]],
  ['lightsdirnoncaster_33',['LightsDirNonCaster',['../struct_ogre_1_1_hlms_base_prop.html#a851305a9b7832f5cea5d11e69a2cb4a9',1,'Ogre::HlmsBaseProp']]],
  ['lightspoint_34',['LightsPoint',['../struct_ogre_1_1_hlms_base_prop.html#a8b9e26636b627ad785c4cdef979e3779',1,'Ogre::HlmsBaseProp']]],
  ['lightsspot_35',['LightsSpot',['../struct_ogre_1_1_hlms_base_prop.html#a05852baddb01052d197367e64b74b6ef',1,'Ogre::HlmsBaseProp']]],
  ['lightsspotparams_36',['LightsSpotParams',['../struct_ogre_1_1_hlms_base_prop.html#a40ff0a3f0e04714a95cf1ce4bd43778e',1,'Ogre::HlmsBaseProp']]],
  ['line_37',['line',['../struct_ogre_1_1_script_token.html#a83500d1c1b1528eca630836658a56f90',1,'Ogre::ScriptToken::line'],['../struct_ogre_1_1_concrete_node.html#a444a4c821038a26b6b35aafdf28ca965',1,'Ogre::ConcreteNode::line'],['../class_ogre_1_1_abstract_node.html#ad2e2e1cc95ee64cd9632cc63e4ca3234',1,'Ogre::AbstractNode::line'],['../struct_ogre_1_1_script_compiler_1_1_error.html#a4f22509637a1cefc4238e11cd1b078c6',1,'Ogre::ScriptCompiler::Error::line']]],
  ['loadaction_38',['loadAction',['../struct_ogre_1_1_render_pass_target_base.html#a2187fa07580e6843929341c59cf35a93',1,'Ogre::RenderPassTargetBase']]],
  ['loader_39',['loader',['../struct_ogre_1_1_resource_group_manager_1_1_resource_declaration.html#a9322aeaf8777145d9fb4d71d30d133f3',1,'Ogre::ResourceGroupManager::ResourceDeclaration']]],
  ['lod_5fmorph_5fcustom_5fparam_40',['LOD_MORPH_CUSTOM_PARAM',['../class_ogre_1_1_terrain.html#aefb36415178b8e15aac901f87b61d3da',1,'Ogre::Terrain']]],
  ['lodbias_41',['lodBias',['../struct_ogre_1_1_update_lod_request.html#ab273fe7d1f1eee28cbc7a7f991ac08d1',1,'Ogre::UpdateLodRequest']]],
  ['lodcallback_42',['lodCallback',['../struct_ogre_1_1_volume_1_1_chunk_parameters.html#a6403e2875cc7b81aefd43ba9f22c2b31',1,'Ogre::Volume::ChunkParameters']]],
  ['lodcamera_43',['lodcamera',['../struct_ogre_1_1_cull_frustum_request.html#ad989603d5f7c91fe101cd5ad622203f7',1,'Ogre::CullFrustumRequest::lodCamera'],['../struct_ogre_1_1_cameras_in_progress.html#a5249df105d3596240a275151efcbd576',1,'Ogre::CamerasInProgress::lodCamera']]],
  ['lodvalue_44',['lodvalue',['../struct_ogre_1_1_entity_mesh_lod_changed_event.html#a296d3f28b84001e84a6153a6b8892dc7',1,'Ogre::EntityMeshLodChangedEvent::lodValue'],['../struct_ogre_1_1_entity_material_lod_changed_event.html#a9f6f11b3dc3989fc136e7796b8c9669c',1,'Ogre::EntityMaterialLodChangedEvent::lodValue']]],
  ['log2_45',['LOG2',['../class_ogre_1_1_math.html#ac2f6916aed097d695a0bffd4ca8a22dd',1,'Ogre::Math']]],
  ['logicalindex_46',['logicalIndex',['../struct_ogre_1_1_gpu_constant_definition.html#a8579926ecde16841abf0d872689b672c',1,'Ogre::GpuConstantDefinition']]],
  ['lowergpuoverhead_47',['lowergpuoverhead',['../struct_ogre_1_1_pbs_property.html#ad8fbdb45aaf5fc17490007c20a2589f8',1,'Ogre::PbsProperty::LowerGpuOverhead'],['../struct_ogre_1_1_unlit_property.html#a50898628559158a300a642ea9de1578b',1,'Ogre::UnlitProperty::LowerGpuOverhead']]],
  ['ltctextureavailable_48',['LtcTextureAvailable',['../struct_ogre_1_1_pbs_property.html#a87b80c888790f7674f372c528409c734',1,'Ogre::PbsProperty']]]
];

==> ogre-next-2.3.3-3-x86_64.pkg.tar.zst: usr/share/OGRE-Next/docs/api/html/search/variables_c.js <==
var searchData=
[
  ['l_0',['l',['../struct_x_client_message_event_data.html#af9ab2e94eb01f68d26563596eb428490',1,'XClientMessageEventData']]],
  ['language_1',['language',['../struct_ogre_1_1_material_script_program_definition.html#a634973d853b04b2cf2af2133d504b257',1,'Ogre::MaterialScriptProgramDefinition']]],
  ['lastcameraposition_2',['lastCameraPosition',['../struct_ogre_1_1_vct_cascade_setting.html#a33b22a34969b7c53ec4003a77b54198e',1,'Ogre::VctCascadeSetting']]],
  ['lastcfactor_3',['lastCFactor',['../struct_ogre_1_1_terrain_quad_tree_node_1_1_lod_level.html#afd5d89ee1eaff154e44347c15af2fba3',1,'Ogre::TerrainQuadTreeNode::LodLevel']]],
  ['lastframeused_4',['lastFrameUsed',['../struct_ogre_1_1_metal_discard_buffer_manager_1_1_unsafe_block.html#a88709353f3c121f08e43392024c70aaa',1,'Ogre::MetalDiscardBufferManager::UnsafeBlock::lastFrameUsed'],['../struct_ogre_1_1_vulkan_discard_buffer_manager_1_1_unsafe_block.html#aa674970178b2b2dc1a34736c98edd4bf',1,'Ogre::VulkanDiscardBufferManager::UnsafeBlock::lastFrameUsed']]],
  ['lastrq_5',['lastRq',['../struct_ogre_1_1_cull_frustum_request.html#ad755d947a31cb517bf34b254577a5257',1,'Ogre::CullFrustumRequest']]],
  ['lasttransitiondist_6',['lastTransitionDist',['../struct_ogre_1_1_terrain_quad_tree_node_1_1_lod_level.html#ac82a3ddf378272493d9d82100c17597a',1,'Ogre::TerrainQuadTreeNode::LodLevel']]],
  ['layer_5fshadow_5fcaster_7',['LAYER_SHADOW_CASTER',['../namespace_ogre_1_1_visibility_flags.html#ab83dacba6153c77d0ea4af5b5f66b07a',1,'Ogre::VisibilityFlags']]],
  ['layer_5fvisibility_8',['LAYER_VISIBILITY',['../namespace_ogre_1_1_visibility_flags.html#a6ef94007305f4ec3dea21e757e3e7fdf',1,'Ogre::VisibilityFlags']]],
  ['layerdeclaration_9',['layerDeclaration',['../struct_ogre_1_1_terrain_1_1_import_data.html#ae3203cf7a78bd3ed0cd75ffe3c107a2e',1,'Ogre::Terrain::ImportData']]],
  ['layerlist_10',['layerList',['../struct_ogre_1_1_terrain_1_1_import_data.html#a3d892ce610f8e6aec873528d042fe72b',1,'Ogre::Terrain::ImportData']]],
  ['layout_11',['layout',['../struct_ogre_1_1_resource_status.html#a2c7d5e06a053baa33611c5a30587ab45',1,'Ogre::ResourceStatus']]],
  ['left_12',['left',['../struct_ogre_1_1_t_rect.html#a7f8310e37638f8790a89f2dd64ff3fe1',1,'Ogre::TRect::left'],['../struct_ogre_1_1_box.html#a88fa61f841bc444d92075d8b6cb2b43b',1,'Ogre::Box::left']]],
  ['lefteyecenter_13',['leftEyeCenter',['../struct_ogre_1_1_hidden_area_vr_settings.html#a61eb37968fd8752cef5be018173a7ab6',1,'Ogre::HiddenAreaVrSettings']]],
  ['lefteyeradius_14',['leftEyeRadius',['../struct_ogre_1_1_hidden_area_vr_settings.html#afbda8be8da981a34199b3786bf1660a3',1,'Ogre::HiddenAreaVrSettings']]],
  ['leftnosecenter_15',['leftNoseCenter',['../struct_ogre_1_1_hidden_area_vr_settings.html#af6f880a9fb10883cfdcd0977de3345de',1,'Ogre::HiddenAreaVrSettings']]],
  ['leftnoseradius_16',['leftNoseRadius',['../struct_ogre_1_1_hidden_area_vr_settings.html#a80aa7c9981f0fb82d2516ed2a1e1ef24',1,'Ogre::HiddenAreaVrSettings']]],
  ['legacymathbrdf_17',['LegacyMathBrdf',['../struct_ogre_1_1_pbs_property.html#aa400163e80e15674460f24e2f0073d89',1,'Ogre::PbsProperty']]],
  ['length_18',['length',['../struct_ogre_1_1_stream_serialiser_1_1_chunk.html#aee59026e7658bc15408b2f92ee1140cb',1,'Ogre::StreamSerialiser::Chunk::length'],['../struct_ogre_1_1_staging_buffer_1_1_destination.html#a94ed749fd12ea165bca3aa12f746eb44',1,'Ogre::StagingBuffer::Destination::length']]],
  ['level_19',['level',['../struct_ogre_1_1_volume_1_1_chunk_request.html#ae5e6c6ee00b6c824bcc782266a440c42',1,'Ogre::Volume::ChunkRequest']]],
  ['levels_20',['levels',['../struct_ogre_1_1_lod_config.html#a7eecc87589b5a3eacfa363850c2fe4c0',1,'Ogre::LodConfig']]],
  ['lexemelen_21',['lexemeLen',['../struct_ogre_1_1_script_token.html#ad065a5c8a457b5e951e2e8f7a79d29f4',1,'Ogre::ScriptToken']]],
  ['lexemeptr_22',['lexemePtr',['../struct_ogre_1_1_script_token.html#a3ff89cd1a7a0a9aa09aee101b354d2e3',1,'Ogre::ScriptToken']]],
  ['light_23',['light',['../class_ogre_1_1_shadow_texture_definition.html#ac5fa1aa9cea5f1ef578cbd4b16196e42',1,'Ogre::ShadowTextureDefinition::light'],['../struct_ogre_1_1_light_closest.html#aa41b81d253b1af2e9951905238e0a7dc',1,'Ogre::LightClosest::light']]],
  ['lightmask_24',['lightMask',['../struct_ogre_1_1_vct_cascade_setting.html#a662957795b2fc34af807f72fb87c0ad1',1,'Ogre::VctCascadeSetting']]],
  ['lightprofilestexture_25',['LightProfilesTexture',['../struct_ogre_1_1_pbs_property.html#acbf91dda99dc9f01792ced8ca41e795d',1,'Ogre::PbsProperty']]],
  ['lights_26',['lights',['../struct_ogre_1_1_light_list_info.html#a29f8b2d7075f792fe24454a5a37b09d0',1,'Ogre::LightListInfo']]],
  ['lightsareaapprox_27',['LightsAreaApprox',['../struct_ogre_1_1_hlms_base_prop.html#aadab57242035ec68cef4db1aa1db601f',1,'Ogre::HlmsBaseProp']]],
  ['lightsarealtc_28',['LightsAreaLtc',['../struct_ogre_1_1_hlms_base_prop.html#afc34b6b99ecc65879f88059d2aa1c4e0',1,'Ogre::HlmsBaseProp']]],
  ['lightsareatexcolour_29',['LightsAreaTexColour',['../struct_ogre_1_1_hlms_base_prop.html#a331c39fb20c11a18fe8677aad9abca78',1,'Ogre::HlmsBaseProp']]],
  ['lightsareatexmask_30',['LightsAreaTexMask',['../struct_ogre_1_1_hlms_base_prop.html#a91ce66216630c5c9c4ec80a169b0abcf',1,'Ogre::HlmsBaseProp']]],
  ['lightsattenuation_31',['LightsAttenuation',['../struct_ogre_1_1_hlms_base_prop.html#a30a8aaf4edf7c988a87ebc7d620f1288',1,'Ogre::HlmsBaseProp']]],
  ['lightsdirectional_32',['LightsDirectional',['../struct_ogre_1_1_hlms_base_prop.html#ad7fc41fdaebead65e4dd966e5b0a0f6e',1,'Ogre::HlmsBaseProp']]],
  ['lightsdirnoncaster_33',['LightsDirNonCaster',['../struct_ogre_1_1_hlms_base_prop.html#a851305a9b7832f5cea5d11e69a2cb4a9',1,'Ogre::HlmsBaseProp']]],
  ['lightspoint_34',['LightsPoint',['../struct_ogre_1_1_hlms_base_prop.html#a8b9e26636b627ad785c4cdef979e3779',1,'Ogre::HlmsBaseProp']]],
  ['lightsspot_35',['LightsSpot',['../struct_ogre_1_1_hlms_base_prop.html#a05852baddb01052d197367e64b74b6ef',1,'Ogre::HlmsBaseProp']]],
  ['lightsspotparams_36',['LightsSpotParams',['../struct_ogre_1_1_hlms_base_prop.html#a40ff0a3f0e04714a95cf1ce4bd43778e',1,'Ogre::HlmsBaseProp']]],
  ['line_37',['line',['../struct_ogre_1_1_concrete_node.html#a444a4c821038a26b6b35aafdf28ca965',1,'Ogre::ConcreteNode::line'],['../class_ogre_1_1_abstract_node.html#ad2e2e1cc95ee64cd9632cc63e4ca3234',1,'Ogre::AbstractNode::line'],['../struct_ogre_1_1_script_compiler_1_1_error.html#a4f22509637a1cefc4238e11cd1b078c6',1,'Ogre::ScriptCompiler::Error::line'],['../struct_ogre_1_1_script_token.html#a83500d1c1b1528eca630836658a56f90',1,'Ogre::ScriptToken::line']]],
  ['loadaction_38',['loadAction',['../struct_ogre_1_1_render_pass_target_base.html#a2187fa07580e6843929341c59cf35a93',1,'Ogre::RenderPassTargetBase']]],
  ['loader_39',['loader',['../struct_ogre_1_1_resource_group_manager_1_1_resource_declaration.html#a9322aeaf8777145d9fb4d71d30d133f3',1,'Ogre::ResourceGroupManager::ResourceDeclaration']]],
  ['lod_5fmorph_5fcustom_5fparam_40',['LOD_MORPH_CUSTOM_PARAM',['../class_ogre_1_1_terrain.html#aefb36415178b8e15aac901f87b61d3da',1,'Ogre::Terrain']]],
  ['lodbias_41',['lodBias',['../struct_ogre_1_1_update_lod_request.html#ab273fe7d1f1eee28cbc7a7f991ac08d1',1,'Ogre::UpdateLodRequest']]],
  ['lodcallback_42',['lodCallback',['../struct_ogre_1_1_volume_1_1_chunk_parameters.html#a6403e2875cc7b81aefd43ba9f22c2b31',1,'Ogre::Volume::ChunkParameters']]],
  ['lodcamera_43',['lodCamera',['../struct_ogre_1_1_cull_frustum_request.html#ad989603d5f7c91fe101cd5ad622203f7',1,'Ogre::CullFrustumRequest::lodCamera'],['../struct_ogre_1_1_cameras_in_progress.html#a5249df105d3596240a275151efcbd576',1,'Ogre::CamerasInProgress::lodCamera']]],
  ['lodvalue_44',['lodValue',['../struct_ogre_1_1_entity_mesh_lod_changed_event.html#a296d3f28b84001e84a6153a6b8892dc7',1,'Ogre::EntityMeshLodChangedEvent::lodValue'],['../struct_ogre_1_1_entity_material_lod_changed_event.html#a9f6f11b3dc3989fc136e7796b8c9669c',1,'Ogre::EntityMaterialLodChangedEvent::lodValue']]],
  ['log2_45',['LOG2',['../class_ogre_1_1_math.html#ac2f6916aed097d695a0bffd4ca8a22dd',1,'Ogre::Math']]],
  ['logicalindex_46',['logicalIndex',['../struct_ogre_1_1_gpu_constant_definition.html#a8579926ecde16841abf0d872689b672c',1,'Ogre::GpuConstantDefinition']]],
  ['lowergpuoverhead_47',['LowerGpuOverhead',['../struct_ogre_1_1_pbs_property.html#ad8fbdb45aaf5fc17490007c20a2589f8',1,'Ogre::PbsProperty::LowerGpuOverhead'],['../struct_ogre_1_1_unlit_property.html#a50898628559158a300a642ea9de1578b',1,'Ogre::UnlitProperty::LowerGpuOverhead']]],
  ['ltctextureavailable_48',['LtcTextureAvailable',['../struct_ogre_1_1_pbs_property.html#a87b80c888790f7674f372c528409c734',1,'Ogre::PbsProperty']]]
];
